.. :changelog:

History
-------

0.1.2 (2013-10-01)
+++++

* Build.get_build() now accepts a job url and optional auth kwarg
  instead of a Job instance.
* Adds unit tests.



0.1.1 (2013-09-28)
++++++++++++++++++

* Bugfix for url transformation to API urls.
* Bugfix for some Build status information always returning False
* Python3 support
* Adds .get_job() to JobSummary
* Adds .get_build() to BuildSummary

0.1.0 (2013-09-27)
++++++++++++++++++

* First release on PyPI.
